@@ -1,3 +1,3 @@
-from rc.provider import gcloud
+from rc.provider import gcloud, azure, digitalocean
 from rc.machine import Machine
 from rc.util import run, RunException, running, run_stream, handle_stream, STDERR, STDOUT, EXIT, go, pmap, as_completed, print_stream, save_stream_to_file
